@@ -51,8 +51,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--enable-loadable-sqlite-extensions' "
                 "'--with-dbmliborder=bdb:gdbm' '--with-computed-gotos' "
                 "'--without-ensurepip' '--with-system-expat' '--with-dtrace' "
-                "'--with-system-libmpdec' '--with-system-ffi' "
-                "'CC=powerpc64le-linux-gnu-gcc' 'CFLAGS=-g "
+                "'--with-system-ffi' 'CC=powerpc64le-linux-gnu-gcc' 'CFLAGS=-g "
                 ' '
                 ' -fstack-protector-strong '
                 "-Wformat -Werror=format-security  -fexceptions' "
@@ -63,8 +62,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.8',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python3.8-ls0buD/python3.8-3.8.10/build-shared/coverage.info',
- 'COVERAGE_REPORT': '/build/python3.8-ls0buD/python3.8-3.8.10/build-shared/lcov-report',
+ 'COVERAGE_INFO': '/build/python3.8-mZWcQz/python3.8-3.8.6/build-shared/coverage.info',
+ 'COVERAGE_REPORT': '/build/python3.8-mZWcQz/python3.8-3.8.6/build-shared/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Include -Wdate-time '
@@ -179,7 +178,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
  'HAVE_DUP3': 1,
- 'HAVE_DYLD_SHARED_CACHE_CONTAINS_PATH': 0,
  'HAVE_DYNAMIC_LOADING': 1,
  'HAVE_ENDIAN_H': 1,
  'HAVE_EPOLL': 1,
@@ -573,7 +571,6 @@ build_time_vars = {'ABIFLAGS': '',
  'LINKCC': 'powerpc64le-linux-gnu-gcc -pthread',
  'LINKFORSHARED': '-Xlinker -export-dynamic -Wl,-O1 -Wl,-Bsymbolic-functions',
  'LIPO_32BIT_FLAGS': '',
- 'LIPO_INTEL64_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
  'LLVM_PROF_FILE': '',
  'LLVM_PROF_MERGER': 'true',
@@ -684,8 +681,7 @@ build_time_vars = {'ABIFLAGS': '',
                              '-D_FORTIFY_SOURCE=2 -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 -Wall '
-              '-g '
-              ' '
+              '-g  '
               ' -fstack-protector-strong '
               '-Wformat -Werror=format-security  -fexceptions  -g -fwrapv -O2 '
               '  ',
@@ -739,7 +735,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.8-ls0buD/python3.8-3.8.10/build-shared',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.8-mZWcQz/python3.8-3.8.6/build-shared',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
@@ -781,10 +777,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.8-ls0buD/python3.8-3.8.10/build-shared '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.8-mZWcQz/python3.8-3.8.6/build-shared '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.8-ls0buD/python3.8-3.8.10/build-shared '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.8-mZWcQz/python3.8-3.8.6/build-shared '
                './python ../Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -807,8 +803,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python3.8-ls0buD/python3.8-3.8.10/build-shared',
- 'abs_srcdir': '/build/python3.8-ls0buD/python3.8-3.8.10/build-shared/..',
+ 'abs_builddir': '/build/python3.8-mZWcQz/python3.8-3.8.6/build-shared',
+ 'abs_srcdir': '/build/python3.8-mZWcQz/python3.8-3.8.6/build-shared/..',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
