@@ -51,8 +51,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--enable-loadable-sqlite-extensions' "
                 "'--with-dbmliborder=bdb:gdbm' '--with-computed-gotos' "
                 "'--without-ensurepip' '--with-system-expat' '--with-dtrace' "
-                "'--with-system-libmpdec' '--with-system-ffi' "
-                "'CC=powerpc64le-linux-gnu-gcc' 'CFLAGS=-g "
+                "'--with-system-ffi' 'CC=powerpc64le-linux-gnu-gcc' 'CFLAGS=-g "
                 ' '
                 ' -fstack-protector-strong '
                 "-Wformat -Werror=format-security  -fexceptions' "
@@ -63,8 +62,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.8',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python3.8-n5W6pS/python3.8-3.8.10/build-shared/coverage.info',
- 'COVERAGE_REPORT': '/build/python3.8-n5W6pS/python3.8-3.8.10/build-shared/lcov-report',
+ 'COVERAGE_INFO': '/build/python3.8-3Yxoq1/python3.8-3.8.10/build-shared/coverage.info',
+ 'COVERAGE_REPORT': '/build/python3.8-3Yxoq1/python3.8-3.8.10/build-shared/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Include -Wdate-time '
@@ -739,7 +738,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.8-n5W6pS/python3.8-3.8.10/build-shared',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.8-3Yxoq1/python3.8-3.8.10/build-shared',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
@@ -781,10 +780,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.8-n5W6pS/python3.8-3.8.10/build-shared '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.8-3Yxoq1/python3.8-3.8.10/build-shared '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.8-n5W6pS/python3.8-3.8.10/build-shared '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.8-3Yxoq1/python3.8-3.8.10/build-shared '
                './python ../Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -807,8 +806,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python3.8-n5W6pS/python3.8-3.8.10/build-shared',
- 'abs_srcdir': '/build/python3.8-n5W6pS/python3.8-3.8.10/build-shared/..',
+ 'abs_builddir': '/build/python3.8-3Yxoq1/python3.8-3.8.10/build-shared',
+ 'abs_srcdir': '/build/python3.8-3Yxoq1/python3.8-3.8.10/build-shared/..',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
